@@ -18,13 +18,13 @@
 
 #include <QTreeView>
 
-#include <kdeversion.h>
+
 
 #include "transferlistmodel.h"
 
 class QKeyEvent;
 
-class KCategoryDrawerV3;
+class KCategoryDrawer;
 
 namespace Konversation
 {
@@ -39,7 +39,7 @@ namespace Konversation
         public:
 
             explicit TransferView(QWidget *parent = 0);
-            virtual ~TransferView();
+            ~TransferView() override;
 
             void addTransfer(Transfer *transfer);
 
@@ -47,7 +47,7 @@ namespace Konversation
             int rowCount() const;
 
             QList<QModelIndex> rowIndexes(int column = 0) const;
-            QList<QModelIndex> selectedIndexes() const;
+            QList<QModelIndex> selectedIndexes() const override;
             QList<QModelIndex> selectedRows(int column = 0) const;
             QModelIndex index(int row, int column) const;
             QModelIndex index(Transfer *transfer) const;
@@ -56,10 +56,10 @@ namespace Konversation
             void selectRow(int row);
             void selectRows(QList<int> rows);
 
-        signals:
+        Q_SIGNALS:
             void runSelectedTransfers();
 
-        public slots:
+        public Q_SLOTS:
             void clear();
 
             void headerCustomContextMenuRequested(const QPoint &pos);
@@ -82,16 +82,15 @@ namespace Konversation
                                        int newStatus, int oldStatus);
 
         protected:
-            virtual void drawRow(QPainter *painter, const QStyleOptionViewItem &option,
-                                 const QModelIndex &index) const;
-            virtual void scrollContentsBy(int dx, int dy);
-            virtual void keyPressEvent(QKeyEvent *event);
+            void drawRow(QPainter *painter, const QStyleOptionViewItem &option,
+                                 const QModelIndex &index) const override;
+            void scrollContentsBy(int dx, int dy) override;
+            void keyPressEvent(QKeyEvent *event) override;
 
-        protected slots:
+        protected Q_SLOTS:
             void rowsAboutToBeRemovedFromModel(const QModelIndex &parent,
                                                int start, int end);
             void rowsRemovedFromModel(int start, int end);
-            void globalSettingsChanged(int category);
 
         private:
             //extra enum needed because ItemDisplayType are not or-able
@@ -113,7 +112,7 @@ namespace Konversation
 
             inline void addItem(Transfer *transfer, TransferItemData::ItemDisplayType type);
 
-            KCategoryDrawerV3 *m_categoryDrawer;
+            KCategoryDrawer *m_categoryDrawer;
 
             TransferListModel *m_dccModel;
             TransferListProxyModel *m_proxyModel;
