@@ -36,7 +36,7 @@ namespace Konversation
 
         public:
             explicit WhiteBoardPaintArea(QWidget* parent = 0);
-            ~WhiteBoardPaintArea();
+            ~WhiteBoardPaintArea() override;
 
         public Q_SLOTS:
             void setTool(Konversation::DCC::WhiteBoardGlobals::WhiteBoardTool tool);
@@ -90,12 +90,12 @@ namespace Konversation
             void colorPicked(const QColor& color);
 
         protected:
-            virtual void paintEvent(QPaintEvent * event);
-            virtual void resizeEvent(QResizeEvent * event);
-            virtual void mousePressEvent(QMouseEvent * event);
-            virtual void mouseReleaseEvent(QMouseEvent * event);
-            virtual void mouseMoveEvent(QMouseEvent * event);
-            virtual void keyPressEvent(QKeyEvent * event);
+            void paintEvent(QPaintEvent * event) override;
+            void resizeEvent(QResizeEvent * event) override;
+            void mousePressEvent(QMouseEvent * event) override;
+            void mouseReleaseEvent(QMouseEvent * event) override;
+            void mouseMoveEvent(QMouseEvent * event) override;
+            void keyPressEvent(QKeyEvent * event) override;
 
         private:
             inline void makeLastPosInvalid();
