@@ -15,27 +15,41 @@
 #include "awaymanager.h"
 #include "irccharsets.h"
 
+#include <QInputDialog>
+
 #include <KEditListWidget>
-#include <KDialog>
 #include <KMessageBox>
 #include <KMessageWidget>
-#include <KInputDialog>
 #include <KUser>
+#include <KConfigGroup>
+#include <QDialogButtonBox>
+#include <QPushButton>
+#include <KStandardGuiItem>
+#include <QVBoxLayout>
 
 namespace Konversation
 {
 
     IdentityDialog::IdentityDialog(QWidget *parent)
-        : KDialog(parent)
+        : QDialog(parent)
     {
-        setCaption( i18n("Identities") );
-        setButtons( Ok|Cancel );
-        setDefaultButton( Ok );
+        setWindowTitle( i18n("Identities") );
+        QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
+        QVBoxLayout *mainLayout = new QVBoxLayout;
+        setLayout(mainLayout);
+        QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
+        okButton->setDefault(true);
+        okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+        connect(buttonBox, &QDialogButtonBox::accepted, this, &IdentityDialog::accept);
+        connect(buttonBox, &QDialogButtonBox::rejected, this, &IdentityDialog::reject);
+        okButton->setDefault(true);
 
         // Initialize the dialog widget
         QWidget* w = new QWidget(this);
         setupUi(w);
-        setMainWidget(w);
+        mainLayout->addWidget(w);
+        mainLayout->addWidget(buttonBox);
+
 
         QGroupBox* nickGroupBox = new QGroupBox(i18n("Nickname"));
         verticalLayout->insertWidget(1, nickGroupBox);
@@ -51,17 +65,17 @@ namespace Konversation
                                           "alternate nicknames for yourself. If your first choice is rejected by the server, "
                                           "Konversation will try the alternate nicknames."));
 
-        newBtn->setIcon(KIcon("list-add"));
-        connect(newBtn, SIGNAL(clicked()), this, SLOT(newIdentity()));
+        newBtn->setIcon(QIcon::fromTheme(QStringLiteral("list-add")));
+        connect(newBtn, &QPushButton::clicked, this, &IdentityDialog::newIdentity);
 
-        copyBtn->setIcon(KIcon("edit-copy"));
-        connect(copyBtn, SIGNAL(clicked()), this, SLOT(copyIdentity()));
+        copyBtn->setIcon(QIcon::fromTheme(QStringLiteral("edit-copy")));
+        connect(copyBtn, &QPushButton::clicked, this, &IdentityDialog::copyIdentity);
 
-        m_editBtn->setIcon(KIcon("edit-rename"));
-        connect(m_editBtn, SIGNAL(clicked()), this, SLOT(renameIdentity()));
+        m_editBtn->setIcon(QIcon::fromTheme(QStringLiteral("edit-rename")));
+        connect(m_editBtn, &QPushButton::clicked, this, &IdentityDialog::renameIdentity);
 
-        m_delBtn->setIcon(KIcon("edit-delete"));
-        connect(m_delBtn, SIGNAL(clicked()), this, SLOT(deleteIdentity()));
+        m_delBtn->setIcon(QIcon::fromTheme(QStringLiteral("edit-delete")));
+        connect(m_delBtn, &QPushButton::clicked, this, &IdentityDialog::deleteIdentity);
 
         foreach(const IdentityPtr &id, Preferences::identityList()) {
             m_identityCBox->addItem(id->getName());
@@ -73,13 +87,12 @@ namespace Konversation
         m_additionalAuthInfo->setCloseButtonVisible(false);
         m_additionalAuthInfo->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum);
 
-        connect(m_authTypeCombo, SIGNAL(currentIndexChanged(int)), this, SLOT(authTypeChanged(int)));
-        m_authTypeCombo->addItem(i18n("Standard NickServ"), "nickserv");
-        m_authTypeCombo->addItem(i18n("Server Password"), "serverpw");
-        m_authTypeCombo->addItem(i18n("SASL"), "saslplain");
-#if KDE_IS_VERSION(4, 8, 3)
-m_authTypeCombo->addItem(i18n("SSL Client Certificate"), "pemclientcert");
-#endif
+        connect(m_authTypeCombo, static_cast<void (KComboBox::*)(int)>(&KComboBox::currentIndexChanged), this, &IdentityDialog::authTypeChanged);
+        m_authTypeCombo->addItem(i18n("Standard NickServ"), QStringLiteral("nickserv"));
+        m_authTypeCombo->addItem(i18n("Server Password"), QStringLiteral("serverpw"));
+        m_authTypeCombo->addItem(i18n("SASL PLAIN"), QStringLiteral("saslplain"));
+        m_authTypeCombo->addItem(i18nc("Cert = Certificate", "SASL EXTERNAL (Cert)"), QStringLiteral("saslexternal"));
+        m_authTypeCombo->addItem(i18n("SSL Client Certificate"), QStringLiteral("pemclientcert"));
 
         // add encodings to combo box
         m_codecCBox->addItems(Konversation::IRCCharsets::self()->availableEncodingDescriptiveNames());
@@ -93,12 +106,12 @@ m_authTypeCombo->addItem(i18n("SSL Client Certificate"), "pemclientcert");
         // Set up signals / slots for identity page
         //connect(m_identityCBox, SIGNAL(activated(int)), this, SLOT(updateIdentity(int)));
 
-        setButtonGuiItem(KDialog::Ok, KGuiItem(i18n("&OK"), "dialog-ok", i18n("Change identity information")));
-        setButtonGuiItem(KDialog::Cancel, KGuiItem(i18n("&Cancel"), "dialog-cancel", i18n("Discards all changes made")));
+        okButton->setToolTip(i18n("Change identity information"));
+        buttonBox->button(QDialogButtonBox::Cancel)->setToolTip(i18n("Discards all changes made"));
 
-        AwayManager* awayManager = static_cast<Application*>(kapp)->getAwayManager();
-        connect(m_identityCBox, SIGNAL(currentIndexChanged(int)), this, SLOT(updateIdentity(int)));
-        connect(this, SIGNAL(identitiesChanged()), awayManager, SLOT(identitiesChanged()));
+        AwayManager* awayManager = Application::instance()->getAwayManager();
+        connect(m_identityCBox, static_cast<void (KComboBox::*)(int)>(&KComboBox::currentIndexChanged), this, &IdentityDialog::updateIdentity);
+        connect(this, &IdentityDialog::identitiesChanged, awayManager, &AwayManager::identitiesChanged);
     }
 
     void IdentityDialog::updateIdentity(int index)
@@ -198,15 +211,15 @@ m_authTypeCombo->addItem(i18n("SSL Client Certificate"), "pemclientcert");
 
         refreshCurrentIdentity();
         Preferences::setIdentityList(m_identityList);
-        static_cast<Application*>(kapp)->saveOptions(true);
+        Application::instance()->saveOptions(true);
         emit identitiesChanged();
-        KDialog::accept();
+        QDialog::accept();
     }
 
     void IdentityDialog::newIdentity()
     {
         bool ok = false;
-        QString txt = KInputDialog::getText(i18n("Add Identity"), i18n("Identity name:"), QString(), &ok, this);
+        QString txt = QInputDialog::getText(this, i18n("Add Identity"), i18n("Identity name:"), QLineEdit::Normal, QString(), &ok);
 
         if(ok && !txt.isEmpty())
         {
@@ -229,7 +242,7 @@ m_authTypeCombo->addItem(i18n("SSL Client Certificate"), "pemclientcert");
     {
         bool ok = false;
         QString currentTxt = m_identityCBox->currentText();
-        QString txt = KInputDialog::getText(i18n("Rename Identity"), i18n("Identity name:"), currentTxt, &ok, this);
+        QString txt = QInputDialog::getText(this, i18n("Rename Identity"), i18n("Identity name:"), QLineEdit::Normal, currentTxt, &ok);
 
         if(ok && !txt.isEmpty())
         {
@@ -272,7 +285,7 @@ m_authTypeCombo->addItem(i18n("SSL Client Certificate"), "pemclientcert");
         }
 
         if(KMessageBox::warningContinueCancel(this, warningTxt, i18n("Delete Identity"),
-            KGuiItem(i18n("Delete"), "edit-delete")) == KMessageBox::Continue)
+            KStandardGuiItem::del()) == KMessageBox::Continue)
         {
             m_identityList.removeOne(m_currentIdentity);
             m_currentIdentity = 0;
@@ -284,7 +297,7 @@ m_authTypeCombo->addItem(i18n("SSL Client Certificate"), "pemclientcert");
     {
         bool ok = false;
         QString currentTxt = m_identityCBox->currentText();
-        QString txt = KInputDialog::getText(i18n("Duplicate Identity"), i18n("Identity name:"), currentTxt, &ok, this);
+        QString txt = QInputDialog::getText(this, i18n("Duplicate Identity"), i18n("Identity name:"), QLineEdit::Normal, currentTxt, &ok);
 
         if(ok && !txt.isEmpty())
         {
@@ -354,23 +367,27 @@ m_authTypeCombo->addItem(i18n("SSL Client Certificate"), "pemclientcert");
     {
         QString authType = m_authTypeCombo->itemData(index).toString();
 
-        bool isNickServ = (authType == "nickserv");
-        bool isSaslPlain = (authType == "saslplain");
-        bool isServerPw = (authType == "serverpw");
-        bool isPemClientCert = (authType == "pemclientcert");
+        bool isNickServ = (authType == QStringLiteral("nickserv"));
+        bool isSaslPlain = (authType == QStringLiteral("saslplain"));
+        bool isSaslExernal = (authType == QStringLiteral("saslexternal"));
+        bool isServerPw = (authType == QStringLiteral("serverpw"));
+        bool isPemClientCert = (isSaslExernal || (authType == QStringLiteral("pemclientcert")));
 
         nickservNicknameLabel->setVisible(isNickServ);
         m_nickservNicknameEdit->setVisible(isNickServ);
         nickservCommandLabel->setVisible(isNickServ);
         m_nickservCommandEdit->setVisible(isNickServ);
-        saslAccountLabel->setVisible(isSaslPlain);
-        m_saslAccountEdit->setVisible(isSaslPlain);
+        saslAccountLabel->setVisible(isSaslPlain || isSaslExernal);
+        m_saslAccountEdit->setVisible(isSaslPlain || isSaslExernal);
         authPasswordLabel->setVisible(!isPemClientCert);
         m_authPasswordEdit->setVisible(!isPemClientCert);
         pemClientCertFileLabel->setVisible(isPemClientCert);
         m_pemClientCertFile->setVisible(isPemClientCert);
         m_additionalAuthInfo->setVisible(isServerPw || isPemClientCert);
 
+        // Clear.
+        m_saslAccountEdit->setPlaceholderText(QString());
+
         for (int i = 0; i < autoIdentifyLayout->count(); ++i)
             autoIdentifyLayout->removeItem(autoIdentifyLayout->itemAt(0));
 
@@ -394,11 +411,17 @@ m_authTypeCombo->addItem(i18n("SSL Client Certificate"), "pemclientcert");
             autoIdentifyLayout->addRow(saslAccountLabel, m_saslAccountEdit);
             autoIdentifyLayout->addRow(authPasswordLabel, m_authPasswordEdit);
         }
-        else if (isPemClientCert)
+        else if (isSaslExernal)
+        {
+            autoIdentifyLayout->addRow(saslAccountLabel, m_saslAccountEdit);
+            m_saslAccountEdit->setPlaceholderText(i18nc("Shown in unfilled line edit", "(optional)"));
+        }
+
+        if (isPemClientCert)
         {
             autoIdentifyLayout->addRow(pemClientCertFileLabel, m_pemClientCertFile);
 
-            m_additionalAuthInfo->setText(i18n("SSL Client Certificate authentication forces SSL to be enabled for a connection, overriding any server settings."));
+            m_additionalAuthInfo->setText(i18n("Certificate-based authentication forces SSL to be enabled for a connection, overriding any server settings."));
             autoIdentifyLayout->addRow(0, m_additionalAuthInfo);
         }
     }
