@@ -57,9 +57,6 @@ namespace Konversation
 
         m_mainWidget = new Ui::ServerGroupDialogUI();
         m_mainWidget->setupUi(mainWidget);
-        mainLayout->setMargin(0);
-        m_mainWidget->serverWidget->layout()->setMargin(0);
-        m_mainWidget->channelWidget->layout()->setMargin(0);
 
         connect(m_mainWidget->m_editIdentityButton, &QPushButton::clicked, this, &ServerGroupDialog::editIdentity);
 
