@@ -56,7 +56,7 @@ class TopicHistoryModel : public QAbstractListModel
 
     public:
         explicit TopicHistoryModel(QObject* parent = 0);
-        ~TopicHistoryModel();
+        ~TopicHistoryModel() override;
 
         QString currentTopic();
 
@@ -68,11 +68,11 @@ class TopicHistoryModel : public QAbstractListModel
         void clearCipher();
 #endif
 
-        QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const;
-        QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const;
+        QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const override;
+        QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override;
 
-        int columnCount(const QModelIndex& parent = QModelIndex()) const;
-        int rowCount(const QModelIndex& parent = QModelIndex()) const;
+        int columnCount(const QModelIndex& parent = QModelIndex()) const override;
+        int rowCount(const QModelIndex& parent = QModelIndex()) const override;
 
         static QString authorPlaceholder();
 
